@@ -16,7 +16,7 @@ local ($^W) = 1; #use warnings ;
 # use bytes ;
 use vars qw($VERSION $XS_VERSION @ISA @EXPORT $AUTOLOAD);
 
-$VERSION = '2.000_04';
+$VERSION = '2.000_05';
 $XS_VERSION = $VERSION; 
 $VERSION = eval $VERSION;
 
@@ -101,8 +101,8 @@ or do {
  
 # Preloaded methods go here.
 
-require IO::Gzip;
-require IO::Gunzip;
+require IO::Compress::Gzip;
+require IO::Uncompress::Gunzip;
 
 use vars qw(@my_z_errmsg);
 
@@ -180,12 +180,12 @@ sub gzopen($$)
     _set_gzerr(0) ;
 
     if ($writing) {
-        $gz = new IO::Gzip($file, Minimal => 1, AutoClose => 1, %defOpts) 
-            or $Compress::Zlib::gzerrno = $IO::Gzip::GzipError;
+        $gz = new IO::Compress::Gzip($file, Minimal => 1, AutoClose => 1, %defOpts) 
+            or $Compress::Zlib::gzerrno = $IO::Compress::Gzip::GzipError;
     }
     else {
-        $gz = new IO::Gunzip($file, Append => 0, AutoClose => 1, Strict => 0) 
-            or $Compress::Zlib::gzerrno = $IO::Gunzip::GunzipError;
+        $gz = new IO::Uncompress::Gunzip($file, Append => 0, AutoClose => 1, Strict => 0) 
+            or $Compress::Zlib::gzerrno = $IO::Uncompress::Gunzip::GunzipError;
     }
 
     return undef
@@ -980,8 +980,8 @@ stream that is embedded in a larger file, without having to resort to opening
 and closing the file multiple times. 
 
 In C<Compress::Zlib> version 2.x, the C<gzopen> interface has been completely
-rewritten to use the L<IO::Gzip|IO::Gzip> for writing gzip files and
-L<IO::Gunzip|IO::Gunzip> for reading gzip files.
+rewritten to use the L<IO::Compress::Gzip|IO::Compress::Gzip> for writing gzip files and
+L<IO::Uncompress::Gunzip|IO::Uncompress::Gunzip> for reading gzip files.
 
 =item 3
 
@@ -994,8 +994,8 @@ Added C<gztell>.
 =back
 
 A more complete and flexible interface for reading/writing gzip files/buffers
-is included with this module.  See L<IO::Gzip|IO::Gzip> and
-L<IO::Gunzip|IO::Gunzip> for more details.
+is included with this module.  See L<IO::Compress::Gzip|IO::Compress::Gzip> and
+L<IO::Uncompress::Gunzip|IO::Uncompress::Gunzip> for more details.
 
 =over 5
 
@@ -1010,7 +1010,7 @@ success and C<undef> on failure.
 When writing a gzip file this interface will always create the smallest
 possible gzip header (exactly 10 bytes). If you want control over the
 information stored in the gzip header (like the original filename or a comment)
-use L<IO::Gzip|IO::Gzip> instead.
+use L<IO::Compress::Gzip|IO::Compress::Gzip> instead.
 
 The second parameter, C<$mode>, is used to specify whether the file is
 opened for reading or writing and to optionally specify a compression
@@ -1257,7 +1257,7 @@ undef.
 
 The C<$buffer> parameter can either be a scalar or a scalar reference.
 
-See L<IO::Gzip|IO::Gzip> for an alternative way to carry out in-memory gzip
+See L<IO::Compress::Gzip|IO::Compress::Gzip> for an alternative way to carry out in-memory gzip
 compression.
 
 =head2 Compress::Zlib::memGunzip
@@ -1272,7 +1272,7 @@ returns undef.
 The C<$buffer> parameter can either be a scalar or a scalar reference. The
 contents of the C<$buffer> parameter are destroyed after calling this function.
 
-See L<IO::Gunzip|IO::Gunzip> for an alternative way to carry out in-memory gzip
+See L<IO::Uncompress::Gunzip|IO::Uncompress::Gunzip> for an alternative way to carry out in-memory gzip
 uncompression.
 
 =head1 COMPRESS/UNCOMPRESS
@@ -1308,7 +1308,7 @@ The source buffer can either be a scalar or a scalar reference.
 Please note: the two functions defined above are I<not> compatible with
 the Unix commands of the same name.
 
-See L<IO::Deflate|IO::Deflate> and L<IO::Inflate|IO::Inflate> included with
+See L<IO::Compress::Deflate|IO::Compress::Deflate> and L<IO::Uncompress::Inflate|IO::Uncompress::Inflate> included with
 this distribution for an alternative interface for reading/writing RFC 1950
 files/buffers.
 
@@ -2210,7 +2210,7 @@ of I<Compress::Zlib>.
 
 =head1 SEE ALSO
 
-L<IO::Gzip>, L<IO::Gunzip>, L<IO::Deflate>, L<IO::Inflate>, L<IO::RawDeflate>, L<IO::RawInflate>, L<IO::AnyInflate>
+L<IO::Compress::Gzip>, L<IO::Uncompress::Gunzip>, L<IO::Compress::Deflate>, L<IO::Uncompress::Inflate>, L<IO::Compress::RawDeflate>, L<IO::Uncompress::RawInflate>, L<IO::Uncompress::AnyInflate>
 
 L<Compress::Zlib::FAQ|Compress::Zlib::FAQ>
 
